==> ui-0.2.43.tgz: package/lib/cjs/Dropdown_deprecated/Dropdown.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _filter = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/filter"));
var _includes = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/includes"));
var _reverse = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/reverse"));
var _slice = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/slice"));
var _map = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/map"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var Styled = _interopRequireWildcard(require("./Dropdown.styled"));
var Icon = _interopRequireWildcard(require("./Dropdown.icon"));
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const DropdownList = _ref => {
  let {
    isTop,
    searchable,
    itemSelect,
    list,
    selectedItem,
    keyword
  } = _ref;
  let tempList = [...list];
  if (keyword.length) {
    tempList = (0, _filter.default)(list).call(list, item => {
      var _context;
      return (0, _includes.default)(_context = item.label.toLowerCase()).call(_context, keyword.toLowerCase());
    });
  }
  if (tempList.length) {
    var _context2;
    const listItem = isTop ? (0, _reverse.default)(_context2 = (0, _slice.default)(tempList).call(tempList)).call(_context2) : tempList;
    return (0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {
      children: (0, _map.default)(listItem).call(listItem, item => (0, _jsxRuntime.jsx)(Styled.DropdownListItem, (0, _assign.default)({
        type: "button",
        onClick: () => itemSelect(item),
        "$isSelected": item.value === selectedItem.value
      }, {
        children: item.label
      }), item.value))
    });
  }
  if (searchable) {
    return (0, _jsxRuntime.jsx)("div", (0, _assign.default)({
      className: "dd-list-item no-result"
    }, {
      children: searchable[1]
    }));
  }
  return (0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {});
};
const Dropdown = _ref2 => {
  let {
    width = '100%',
    onChange = e => console.log(e),
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onClickOpen = () => {},
    title = '선택해주세요',
    list = [],
    searchable,
    selected = {
      value: '',
      label: ''
    },
    isTop = false,
    size = 'small',
    arrowUpIcon,
    arrowDownIcon
  } = _ref2;
  const [isListOpen, setListOpen] = (0, _react.useState)(false);
  const [selectedItem, setSelectedItem] = (0, _react.useState)(selected);
  const [keyword, setKeyword] = (0, _react.useState)('');
  const dropdownRef = (0, _react.useRef)(null);
  // const searchFieldRef = useRef<HTMLInputElement>(null);
  const close = () => setListOpen(false);
  const handleClick = (0, _react.useCallback)(e => {
    if (dropdownRef.current && !dropdownRef.current.contains(e.target)) {
      close();
    }
  }, []);
  (0, _react.useEffect)(() => {
    document.addEventListener('click', handleClick);
    return () => {
      document.removeEventListener('click', handleClick);
    };
  }, [handleClick]);
  const itemSelect = _ref3 => {
    let {
      value,
      label
    } = _ref3;
    setSelectedItem({
      value,
      label
    });
    setListOpen(false);
    if (selectedItem.value !== value) onChange({
      value,
      label
    });
  };
  const toggleList = () => {
    if (!isListOpen) {
      onClickOpen();
    }
    setListOpen(!isListOpen);
    setKeyword('');
  };
  const filterList = event => {
    setKeyword(event.target.value.toLowerCase());
  };
  return (0, _jsxRuntime.jsxs)(Styled.DSDropdownWrapper, (0, _assign.default)({
    ref: dropdownRef,
    onClick: toggleList,
    "$size": size,
    "$width": width,
    "$isOpen": isListOpen,
    "$isTop": isTop
  }, {
    children: [(0, _jsxRuntime.jsxs)(Styled.DropdownButton, (0, _assign.default)({
      type: "button"
    }, {
      children: [(0, _jsxRuntime.jsx)(Styled.DropdownTitle, {
        children: selectedItem.label || title
      }), isTop ? (0, _jsxRuntime.jsx)("div", {
        children: arrowUpIcon || (0, _jsxRuntime.jsx)(Icon.UpArrow, {})
      }) : (0, _jsxRuntime.jsx)("div", {
        children: arrowDownIcon || (0, _jsxRuntime.jsx)(Icon.DownArrow, {})
      })]
    })), isListOpen && (0, _jsxRuntime.jsxs)(Styled.DropdownList, (0, _assign.default)({
      "$isTop": isTop
    }, {
      children: [searchable && (0, _jsxRuntime.jsx)(Styled.DropdownListSearchBar
      // ref={searchFieldRef}
      , {
        // ref={searchFieldRef}
        placeholder: searchable[0],
        onClick: e => e.stopPropagation(),
        onChange: filterList
      }), (0, _jsxRuntime.jsx)(Styled.DropdownScrollList, {
        children: (0, _jsxRuntime.jsx)(DropdownList, {
          isTop: isTop,
          itemSelect: itemSelect,
          searchable: searchable,
          selectedItem: selectedItem,
          list: list,
          keyword: keyword
        })
      })]
    }))]
  }));
};
var _default = Dropdown;
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/Dropdown_deprecated/Dropdown.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _filter = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/filter"));
var _includes = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/includes"));
var _reverse = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/reverse"));
var _slice = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/slice"));
var _map = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/map"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var Styled = _interopRequireWildcard(require("./Dropdown.styled"));
var Icon = _interopRequireWildcard(require("./Dropdown.icon"));
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const DropdownList = _ref => {
  let {
    isTop,
    searchable,
    itemSelect,
    list,
    selectedItem,
    keyword
  } = _ref;
  let tempList = [...list];
  if (keyword.length) {
    tempList = (0, _filter.default)(list).call(list, item => {
      var _context;
      return (0, _includes.default)(_context = item.label.toLowerCase()).call(_context, keyword.toLowerCase());
    });
  }
  if (tempList.length) {
    var _context2;
    const listItem = isTop ? (0, _reverse.default)(_context2 = (0, _slice.default)(tempList).call(tempList)).call(_context2) : tempList;
    return (0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {
      children: (0, _map.default)(listItem).call(listItem, item => (0, _jsxRuntime.jsx)(Styled.DropdownListItem, (0, _assign.default)({
        type: "button",
        onClick: () => itemSelect(item),
        "$isSelected": item.value === selectedItem.value
      }, {
        children: item.label
      }), item.value))
    });
  }
  if (searchable) {
    return (0, _jsxRuntime.jsx)("div", (0, _assign.default)({
      className: "dd-list-item no-result"
    }, {
      children: searchable[1]
    }));
  }
  return (0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {});
};
const Dropdown = _ref2 => {
  let {
    width = '100%',
    onChange = e => console.log(e),
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    onClickOpen = () => {},
    title = '선택해주세요',
    list = [],
    searchable,
    selected = {
      value: '',
      label: ''
    },
    isTop = false,
    size = 'small',
    arrowUpIcon,
    arrowDownIcon
  } = _ref2;
  const [isListOpen, setListOpen] = (0, _react.useState)(false);
  const [selectedItem, setSelectedItem] = (0, _react.useState)(selected);
  const [keyword, setKeyword] = (0, _react.useState)('');
  const dropdownRef = (0, _react.useRef)(null);
  // const searchFieldRef = useRef<HTMLInputElement>(null);
  const close = () => setListOpen(false);
  const handleClick = (0, _react.useCallback)(e => {
    if (dropdownRef.current && !dropdownRef.current.contains(e.target)) {
      close();
    }
  }, []);
  (0, _react.useEffect)(() => {
    document.addEventListener('click', handleClick);
    return () => {
      document.removeEventListener('click', handleClick);
    };
  }, [handleClick]);
  const itemSelect = _ref3 => {
    let {
      value,
      label
    } = _ref3;
    setSelectedItem({
      value,
      label
    });
    setListOpen(false);
    if (selectedItem.value !== value) onChange({
      value,
      label
    });
  };
  const toggleList = () => {
    if (!isListOpen) {
      onClickOpen();
    }
    setListOpen(!isListOpen);
    setKeyword('');
  };
  const filterList = event => {
    setKeyword(event.target.value.toLowerCase());
  };
  return (0, _jsxRuntime.jsxs)(Styled.DSDropdownWrapper, (0, _assign.default)({
    ref: dropdownRef,
    onClick: toggleList,
    "$size": size,
    "$width": width,
    "$isOpen": isListOpen,
    "$isTop": isTop
  }, {
    children: [(0, _jsxRuntime.jsxs)(Styled.DropdownButton, (0, _assign.default)({
      type: "button"
    }, {
      children: [(0, _jsxRuntime.jsx)(Styled.DropdownTitle, {
        children: selectedItem.label || title
      }), isTop ? (0, _jsxRuntime.jsx)("div", {
        children: arrowUpIcon || (0, _jsxRuntime.jsx)(Icon.UpArrow, {})
      }) : (0, _jsxRuntime.jsx)("div", {
        children: arrowDownIcon || (0, _jsxRuntime.jsx)(Icon.DownArrow, {})
      })]
    })), isListOpen && (0, _jsxRuntime.jsxs)(Styled.DropdownList, (0, _assign.default)({
      "$isTop": isTop
    }, {
      children: [searchable && (0, _jsxRuntime.jsx)(Styled.DropdownListSearchBar
      // ref={searchFieldRef}
      , {
        // ref={searchFieldRef}
        placeholder: searchable[0],
        onClick: e => e.stopPropagation(),
        onChange: filterList
      }), (0, _jsxRuntime.jsx)(Styled.DropdownScrollList, {
        children: (0, _jsxRuntime.jsx)(DropdownList, {
          isTop: isTop,
          itemSelect: itemSelect,
          searchable: searchable,
          selectedItem: selectedItem,
          list: list,
          keyword: keyword
        })
      })]
    }))]
  }));
};
var _default = exports.default = Dropdown;
